#
# spec file for package musescore
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         rname mscore
%define         version_lesser 3.4
%define fontdir %{_datadir}/fonts/%{name}
%define docdir  %{_docdir}/%{name}
Name:           musescore
Version:        3.4.2
Release:        lp152.2.17
Summary:        A WYSIWYG music score typesetter
# Musescore code license is GPL-2.0
# Software in thirdparty is licensed under their own license
# Documentation is CC-SA
License:        GPL-2.0-only AND GPL-2.0-or-later AND LGPL-2.1-only AND LGPL-3.0-only AND MIT
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            https://musescore.org
Source0:        https://github.com/musescore/MuseScore/archive/v%{version}/MuseScore-%{version}.tar.gz
Source1:        %{rname}.desktop
# PATCH-FIX-UPSTREAM: see https://github.com/musescore/MuseScore/releases
Patch0:         correct-revision.patch
# PATCH-FIX-OPENSUSE: really use qmake-qt5
Patch1:         use-qtmake-qt5.patch
# PATCH-FIX-OPENSUSE: don't install qtwebengine files, they are not needed
Patch2:         use-system-qtwebengine-files.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libQt5Help5
BuildRequires:  libQt5QuickTemplates2-devel
BuildRequires:  libmp3lame-devel
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig
BuildRequires:  portmidi-devel
BuildRequires:  strip-nondeterminism
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5QuickControls2)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5UiTools)
# TODO: why does it fail with qtwebengine?
BuildRequires:  pkgconfig(Qt5WebEngine)
BuildRequires:  pkgconfig(Qt5WebEngineCore)
BuildRequires:  pkgconfig(Qt5WebEngineWidgets)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(Qt5XmlPatterns)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-mainloop-glib)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(portaudiocpp)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisenc)
BuildRequires:  pkgconfig(vorbisfile)
Requires:       %{name}-fonts = %{version}-%{release}
Requires:       libqt5-qtgraphicaleffects
Requires:       libqt5-qtquickcontrols2

%description
MuseScore is a graphical music typesetter. It allows for note entry on a
virtual note sheet. It has an integrated sequencer for immediate playing of the
score. MuseScore can import and export MusicXml and standard MIDI files.

%package fonts
Summary:        MuseScore fonts
License:        GPL-3.0-or-later WITH Font-exception-2.0 AND OFL-1.1
Group:          System/X11/Fonts
BuildArch:      noarch

%description fonts
Additional fonts for use by the MuseScore music notation program.

%prep
%autosetup -p1 -n MuseScore-%{version}

# fix EOL encoding
sed 's/\r$//' fonts/bravura/OFL-FAQ.txt > tmpfile
touch -r fonts/bravura/OFL-FAQ.txt tmpfile
mv -f tmpfile fonts/bravura/OFL-FAQ.txt

sed 's/\r$//' thirdparty/rtf2html/README > tmpfile
touch -r thirdparty/rtf2html/README tmpfile
mv -f tmpfile thirdparty/rtf2html/README

sed 's/\r$//' thirdparty/rtf2html/README.ru > tmpfile
touch -r thirdparty/rtf2html/README.ru tmpfile
mv -f tmpfile thirdparty/rtf2html/README.ru

# remove executable bit
chmod -x fonts/gootville/readme.txt

%build
%define __builddir build.release
%cmake \
       -DCMAKE_BUILD_TYPE=RELEASE \
       -DUSE_SYSTEM_FREETYPE="ON" \
       -DBUILD_WEBENGINE="ON"
%make_jobs lrelease all

# Put the desktop file in place for the packaging
cp %{SOURCE1} .

%install
%cmake_install
strip-nondeterminism -t zip %{buildroot}%{_datadir}/%{rname}-%{version_lesser}/workspaces/*.workspace

# install fonts
mkdir -p %{buildroot}%{fontdir}
install -p -m 644 fonts/*.ttf %{buildroot}/%{fontdir}

# update desktop file
%suse_update_desktop_file -n %{rname} AudioVideo AudioVideoEditing

# also package additional demos
mkdir -p %{buildroot}%{_datadir}/%{rname}-%{version_lesser}/demos
install -p -m 644 demos/*.mscz %{buildroot}%{_datadir}/%{rname}-%{version_lesser}/demos

# collect doc files
install -d -m 755 %{buildroot}%docdir
install -p -m 644 thirdparty/beatroot/COPYING         %{buildroot}%docdir/COPYING.beatroot
install -p -m 644 thirdparty/beatroot/README.txt      %{buildroot}%docdir/README.txt.beatroot
install -p -m 644 thirdparty/intervaltree/README      %{buildroot}%docdir/README.intervaltree
install -p -m 644 thirdparty/ofqf/README.md           %{buildroot}%docdir/README.md.ofqf
install -p -m 644 thirdparty/rtf2html/ChangeLog       %{buildroot}%docdir/ChangeLog.rtf2html
install -p -m 644 thirdparty/rtf2html/COPYING.LESSER  %{buildroot}%docdir/COPYING.LESSER.rtf2html
install -p -m 644 thirdparty/rtf2html/README          %{buildroot}%docdir/README.rtf2html
install -p -m 644 thirdparty/rtf2html/README.mscore   %{buildroot}%docdir/README.mscore.rtf2html
install -p -m 644 thirdparty/rtf2html/README.ru       %{buildroot}%docdir/README.ru.rtf2html
install -p -m 644 thirdparty/singleapp/LGPL_EXCEPTION.txt %{buildroot}%docdir/LGPL_EXCEPTION.txt.singleapp
install -p -m 644 thirdparty/singleapp/LICENSE.GPL3   %{buildroot}%docdir/LICENSE.GPL3.singleapp
install -p -m 644 thirdparty/singleapp/LICENSE.LGPL   %{buildroot}%docdir/LICENSE.LGPL.singleapp
install -p -m 644 thirdparty/singleapp/README.TXT     %{buildroot}%docdir/README.TXT.singleapp

# aeolus not included in this build
#install -p -m 644 aeolus/AUTHORS                     %%{buildroot}%%{docdir}/AUTHORS.aeolus
#install -p -m 644 aeolus/COPYING                     %%{buildroot}%%{docdir}/COPYING.aeolus
#install -p -m 644 aeolus/README                      %%{buildroot}%%{docdir}/README.aeolus
#install -p -m 644 aeolus/README.mscore               %%{buildroot}%%{docdir}/README.mscore.aeolus
#install -p -m 644 aeolus/README.mscore1              %%{buildroot}%%{docdir}/README.mscore1.aeolus

install -p -m 644 bww2mxml/COPYING                    %{buildroot}%docdir/COPYING.bww2mxml
install -p -m 644 bww2mxml/README                     %{buildroot}%docdir/README.bww2mxml
install -p -m 644 effects/chorus/COPYING              %{buildroot}%docdir/COPYING.chorus
install -p -m 644 effects/chorus/README               %{buildroot}%docdir/README.chorus
install -p -m 644 effects/compressor/README           %{buildroot}%docdir/README.compressor
install -p -m 644 share/sound/README.md               %{buildroot}%docdir/README.md.sound
install -p -m 644 share/locale/README.md              %{buildroot}%docdir/README.md.locale
install -p -m 644 share/instruments/README.md         %{buildroot}%docdir/README.md.instruments
install -p -m 644 share/wallpaper/COPYRIGHT           %{buildroot}%docdir/COPYING.wallpaper
install -p -m 644 zerberus/README                     %{buildroot}%docdir/README.zerberus

%fdupes %{buildroot}/%{_prefix}

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post
%mime_database_post
%endif

%if 0%{?suse_version} < 1500
%postun
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun
%endif

%files
%{_bindir}/%{name}
%{_bindir}/%{rname}
%{_datadir}/metainfo/org.musescore.MuseScore.appdata.xml
%{_datadir}/applications/%{rname}.desktop
%{_datadir}/mime/packages/*
%{_datadir}/icons/hicolor/*
%dir %{_datadir}/%{rname}-%{version_lesser}
%{_datadir}/%{rname}-%{version_lesser}/*
%{_mandir}/man1/*
%doc README.md
%license LICENSE.GPL
%dir %docdir
%doc %docdir/*

%files fonts
%dir %{fontdir}
%{fontdir}/*.ttf
%doc fonts/README.md
%doc fonts/bravura/bravura-text.md
%doc fonts/bravura/OFL-FAQ.txt
%doc fonts/bravura/OFL.txt
%doc fonts/gootville/readme.txt

%changelog
* Mon Apr 27 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Normalize timestamps in .workspace zip files
  to make package build reproducible (boo#1047218)
* Fri Feb  7 2020 Cor Blom <cornelis@solcon.nl>
- Update to 3.4.2:
  * Telemetry dialog was not accessible for visually impaired people
  * Drum input palette worked incorrectly due to the changes
    involving single click behaviour
  * MuseScore crashed when pressing numbers/letters in a different
    voice when inputting tabs
  * Hidden pedal items were no longer displayed
  * "L" letter could not be typed when entering text
- Remove 0001-fix-299654-Crash-on-startup-with-Qt-5.14.patch (part
  of tarball now)
- update correct-revision.patch
* Tue Jan 28 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 3.4.1. Changes since 3.3.4:
  * MuseScore crashed after closing a menu bar pop-up window
    if no score is opened
  * Audio glitches on note input and playback happened on
    macOS and other platforms
  * Parts corruption happened on timewise delete of individual beats
  * Crash happened when undoing "Beam middle" setting on a single note
  * Pedal lines alignment applied to the whole system, not individual
    staff
  * "Don't play trill" option silenced the note playback
  * Slurs on small staves were displaced in some cases
  * Barline handles were drawn incorrectly after dragging one
  * Strings in the Part dialogue were ambiguous
  * Y Offset value of fretboards didn't restore after undoing
    the values being changed from Edit Mode
  * Replacing a note with an accidental left the accidental
    on the new note
  * Adding Intervals (above/below) didn't take into consideration
    the accidental toggle state
  * Multiple chord symbols attached to same note didn't copy as
    part of the range
  * Strings in fret diagrams without "X" or "O" displayed as "?" on Linux
  * MuseScore crashed when changing a triplet's rest's duration
  * Images attached to rests weren't imported from MuseScore 2
  * Tremolo Bar dialog had multiple UX issues
  * AppImage: system printers weren't available in the print dialog
- Check https://musescore.org/fr/handbook/developers-handbook/release-notes
  for the complete list of changes.
- Update correct-revision.patch
- Update use-system-qtwebengine-files.patch
- Add upstream patch 0001-fix-299654-Crash-on-startup-with-Qt-5.14.patch
* Wed Dec  4 2019 Cor Blom <cornelis@solcon.nl>
- Update to 3.3.4:
  Fixes:
  * Palette names were scrambled and nearly impossible to read
    (Windows 7)
  * Scale of palette was incorrect for high and low DPI displays
  * Courtesy accidentals disappeared after an octave change using
    Ctrl(Cmd)+Up/Down
  * Crash reports could not be sent
- Updated correct-revision.patch
* Tue Nov 26 2019 Cor Blom <cornelis@solcon.nl>
- Update to 3.3.3:
  Improvements:
  * Tie button behaves as a toggle now
  * Enable changing notes duration if selecting note stem, hook or
    a range
  * Visual improvements for palettes
  * Mark notes that are out of instrument range with red or yellow
    color even when they are selected
  * Save Online is now fully synchronised with the musescore.com
    upload page
  Fixes
  * Export Pdf on Mac with Muse Jazz Text was garbled and
    unreadable if no printers were setup on a machine
  * Entering notes with mouse failed in Italian TAB
  * Scoreview jumped back to start of score during note input on
    (auto)save
  * Sticking could not be copy-pasted
  * Extensions could not be installed on macOS Catalina
- Update correct-revision.patch
* Fri Nov 15 2019 Cor Blom <cornelis@solcon.nl>
- Update to 3.3.2:
  * "Save online" failed in some cases
- Add patches to make qtwebengine work: use-qtmake-qt5.patch and
  use-system-qtwebengine-files.patch
* Wed Nov 13 2019 Cor Blom <cornelis@solcon.nl>
- Update to 3.3.1:
  * MuseScore crashed on startup in some cases on Windows 7
  * Palettes were incorrectly placed when using multiple HighDPI
    monitors and scaling
  * Palettes disappeared on Ubuntu 18.04 in some cases
- Update correct-revision.patch
- Remove line from spec to remove rtf2html binary: it is no longer
  part of the source tarball
* Tue Nov  5 2019 Cor Blom <cornelis@solcon.nl>
- -DCMAKE_BUILD_TYPE=RELEASE need to be set explicitly
  (boo#1155809)
- Convert BuildRequires to pkgconfig style and updated them according
  to recommendations of upstream. It solves a couple of cmake errors
- Added reminder to look into qtwebengine support, which is not
  essential but nice to have. Enabling it gives a build error
* Mon Nov  4 2019 Cor Blom <cornelis@solcon.nl>
- Add libqt5-qtgraphicaleffects and libqt5-qtquickcontrols2 as
  requires (boo#1155704)
* Thu Oct 31 2019 Cor Blom <cornelis@solcon.nl>
- Update to 3.3.0:
  This is a major update with new functions. For details see the
  announcement: https://musescore.org/en/3.3
- Update correct-revision.patch to latest revision number
* Thu Jul 11 2019 Cor Blom <cornelis@solcon.nl>
- Update to 3.2.3:
  * Articulations didn't play properly in MDL instruments
  * Tuplets layout was broken in some cases
  * Fingering jumped unpredictably in some cases
  * Switching between workspaces erased the enabled plugins
  * Bugfixes. For details see https://musescore.org/en/3.2.3
- update correct-revision.patch
* Sun Jun 30 2019 Cor Blom <cornelis@solcon.nl>
- Update to 3.2.2:
  + Most important improvements:
  * Sticking (the process of assigning certain notes to either our
    left or right hand) as a new command
  * Make basic colors of the application including voice colors consistent
  * 7/8 time signature was added to advanced workspace and master
    palette
  * Avoid poor alignment of hairpins to dynamics bound to the segment
    before hairpin start
  * Add style settings allowing MDL templates to follow basic drum
    line notation rules better
  * Double/triple-clicking in a text editing mode now selects a
    word/paragraph respectively
  + Also numerous fixes, for details see github release page:
  * https://github.com/musescore/MuseScore/releases
- Update correct-revision.patch
* Fri Jun  7 2019 Cor Blom <cornelis@solcon.nl>
- Update to 3.1.0:
  New:
  * Single-note dynamics playback - long notes can play dynamic changes
  * Updated soundfont that supports single-note dynamics out of the box
  * High quality soundfont with better strings and synth instruments
    available as an extension in the Resource Manager
  * Option to completely disable Auto Placement
  * Elements can cross staves still participating in Auto Placement
  * Half-time/Double-time feature that shortens and lengthens rhythms
    on copy-pasting
  * Linearization feature that unrolls all repeats
  * Internal computational approach that allows creating 256th, 512th,
    1024th notes and any kind of compound tuplets
  * Online documentation for Plugin API is available
  Further:
  * Several improvements and a number of bugfixes
- Update correct-revision.patch
* Fri Mar 15 2019 Cor Blom <cornelis@solcon.nl>
- Update to 3.0.5:
  Improvements:
  * The whole chord sounds when iterating over notes with left-right
    arrows
  * Support more properties for fingering
  * Add more properties for Plugin API
  * Optimise New Score Wizard start time and layout calculations
  Fixes:
  * MuseScore 3.0.4 crashed on startup on macOS
  * Score margins and related staves positioning were calculated
    incorrectly
  * Spacers worked incorrectly when interacting with page borders
  * Measure counting was wrong when setting a custom offset value
  * Keyboard navigation in Single Page view worked incorrectly
  * MuseScore crashed on finishing work on Windows
  * MuseScore crashed when changing Time Signature in parts
  * MuseScore crashed when selecting a bracket in edit mode
* Fri Mar  1 2019 Cor Blom <cornelis@solcon.nl>
- Update to 3.0.4:
  Fixes:
  * All instruments played as piano in some specific cases
  * "Save online" login screen didn't work on Mac
  * Removing section break crashed the editor in some cases
  * Copying measure repeats didn't work
  * Brass Quartet and Brass Quintet templates couldn't be opened
- Update to 3.0.3:
  New
  * New crash report facility (this is disabled in our build for now)
  Improvements
  * Whole score playback can be turned on when in the Part tab
    using the mixer. Part playback works by default in in the Part tab
  * Improved global performance
  * Drag-and-drop user experience is improved
  Fixes
  * Caesuras and sections breaks didn't cause pauses in playback
  * Some properties were not properly saved
  * Fermatas over barlines could not be added
  * Articulations could not be added to grace notes
  * Redundant key/time signatures appeared in Page/Continuous view
    and Parts
  * Visibility was not properly applied
  * Ties failed to be copied-pasted in a score with parts
  * Keyboard navigation in Continuous View was broken
- Updated correct-revision.patch to reflect new version
* Fri Feb 15 2019 cornelis@solcon.nl
- Update to 3.0.2:
  * Improvements
    + Reworked login screen when using Save Online allows signing in via
    Facebook and Google and creating an account from within the editor
    + New easy fingering input mode and other fingering improvements
  * Fixes
    + Plugins framework didn't work
    + Grace notes displayed the wrong size in TAB staves
    + Default window size was too large on a multi-monitor setup
    + Color was not available as a text style setting, including issues with
    coloring lyrics for different voices
    + Slurs were not exported properly to MusicXML
    + Tempo text was not imported properly from MusicXML
- Updated correct-revision.patch
* Sat Jan 19 2019 Cor Blom <cornelis@solcon.nl>
- Update to 3.0.1:
  * Improvements
    + Redesign of New Score Wizard makes it easier to search
    templates, provides better score previews, and significantly
    improves accessibility for blind users
    + Reworked Mixer UI allows minimizing and making it dockable
    + Better automatic placement of hairpins and dynamics
    + Better import of 2.X scores
  * Fixes
    + Properties were not saved properly in a number of cases
    + Layout was broken after operations with measure rests and
    tuplets
    + Time signatures appeared incorrectly in some cases and might
    lead to crash
    + Using the implode tool on notes connected with slurs led to
    crashes
    + Editing a barline was applied incorrectly
    + Context menu on instrument names didn't appear
    + Pages with landscape orientation were cropped when printing
    + Playback went crazy on saving
    + Tempo was applied incorrectly in certain cases involving
    fermatas
    + Slurs were lost or detached in some cases
    + Autoplacement couldn't be switched off for stems and arpeggio
- Added correct-revision.patch: revision number in the source
  tarballs on github is wrong
* Fri Jan  4 2019 Cor Blom <cornelis@solcon.nl>
- Update to 3.0.0: A major feature release:
  * Musical notation
    + Automatic placement - potential collisions between elements
    are detected and resolved automatically, allowing you to easily
    create great-looking scores with little need for manual adjustment
    + Improved parts facility - link parts to specific voices within
    a staff
    + System dividers - automatically generate dividers between
    systems
    + Staff type changes - change staff size, number of lines, and
    other properties mid-score
    + Temporary and cutaway staves - staves may appear and disappear
    as needed, including the ability to have empty measures be
    completely invisible
    + MuseJazz font - give all elements in your scores a handwritten
    appearance
    + Named noteheads - automatically display pitch names in
    noteheads using a variety of different naming schemes
  * Usability
    + Tours - get online help automatically as you need it
    + Timeline - navigate using a graphical overview of the music
    structure of your score that shows rehearsal marks, changes of
    tempo, key, and time signature, etc.
    + Score comparison tool - easily view differences between
    versions of a score
    + Single page mode - vertically scrolling view of your score
    + Improved Inspector - control more element properties and set
    style defaults directly from the Inspector window, including new
    above/below placement settings
    + Palette search - enter a search term to quickly find any
    symbol
    + Timewise note input and editing - insert and deletes notes and
    rests within measures, automatically shifting subsequent music
    forwards or backwards
    + Next/previous element - Alt+Right/Left shortcuts to navigate
    through each element of your score
    + Auto-update - no longer necessary to download and install new
    versions from musescore.org
  * Playback
    + Improved Mixer - mute individual voices, collapse channels
    into a single column, assign MIDI ports and channels
    + Improved Piano Roll Editor - easier control of the playback
    parameters of each note in your score
    + Redesigned Play Panel - docked within main window
- Removed no longer necessary remove_diff_match_patch.diff: the library
  is replaced and removed because of a conflict in licensing.
- Removed now included fix-build-qt512.patch
* Thu Dec 27 2018 Cor Blom <cornelis@solcon.nl>
- Add fix-build-qt512.patch to fix build with Qt 5.12
* Mon Oct  1 2018 cornelis@solcon.nl
- Add remove_diff_match_patch.diff to solve license conflict: it
  removes the Apache licensed diff_patch_match library.
* Mon Sep 17 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description. Do not run fdupes over
  the default partition boundaries.
* Fri Sep 14 2018 Cor Blom <cornelis@solcon.nl>
- Cleaned up spec file a bit.
* Wed Aug  8 2018 dliw@posteo.net
- Update to 2.3.2
  * Release 2.3.2
    Released 31 July 2018
    For a complete description of what has changed for 2.3.2
    see https://musescore.org/en/handbook/developers-handbook/release-notes/release-notes-musescore-232
* Mon Jul 30 2018 dliw@posteo.net
- Update to 2.3.1
  * Release 2.3.1
    Released 6 July 2018
    For a complete description of what has changed for 2.3.1
    see https://musescore.org/en/handbook/developers-handbook/release-notes/release-notes-musescore-231
  * Release 2.3.0
    Released 29 June 2018
    For a complete description of what has changed for 2.3.0
    see https://musescore.org/en/handbook/developers-handbook/release-notes/release-notes-musescore-23
- Remove patch musescore-fix-include.patch (no longer needed)
* Sat Jun  9 2018 dliw@posteo.net
- Update to 2.2.1
  * Release 2.2.1
    Released 3 April 2018
    For a complete description of what has changed for 2.2.1
    see https://musescore.org/en/handbook/developers-handbook/release-notes/release-notes-musescore-221
  * Release 2.2.0
    Released 27 March 2018
    For a complete description of what has changed for 2.2.0
    see https://musescore.org/en/handbook/developers-handbook/release-notes/release-notes-musescore-22
  * Release 2.1.0
    Released 2 May 2017
    For a complete description of what has changed for 2.1.0
    see https://musescore.org/en/developers-handbook/release-notes/release-notes-musescore-2.1
  * Release 2.0.3
    Released 6 April 2017
    For a complete description of what has changed for 2.0.3
    see https://musescore.org/en/developers-handbook/release-notes/release-notes-musescore-2.0.3
- Clean up spec file
- Obsolete musescore-doc
- Fix build with Qt >= 5.11
  new patch musescore-fix-include.patch (from upstream)
* Fri Nov 13 2015 cornelis@solcon.nl
- add make-lame-optional.diff (backport from upstream) so that we
  can build without lame
- lowered Qt requires to 5.3.0 (as CMakefilelist has it)
* Tue Sep  1 2015 wbauer@tmo.at
- fix package dependencies (boo#943985)
* Tue Jul 21 2015 cgardner@suse.com
- Version 2.0.2, released July 2015.
* Wed Mar 25 2015 cgardner@suse.com
- Update to consistently require Qt5 (5.4.2) for all distros from this repo
  to reduce problems with mismatched Qt libraries preventing mscore from loading
* Mon Mar 23 2015 cgardner@suse.com
- Version 2.0, released 23 March 2014.  See
  http://musescore.org/en/node/50996
  This is the first major release of MuseScore since version 1.3
* Sun Oct 27 2013 schoett@gmx.de
- Install mime data file mscore.xml.
* Wed Feb 27 2013 cgardner@suse.com
- Version 1.3, released 27 Feb 2013.  See
  http://musescore.org/en/developers-handbook/release-notes/release-notes-musescore-1.3
  This release has a very limited number of bug fixes over 1.2.
* Thu Mar 15 2012 cgardner@suse.com
- Added /etc/modules-load.d/musescore.conf to load snd-seq on openSUSE 12+
* Tue Mar 13 2012 cgardner@suse.com
- Version 1.2, released 13 March 2012.  See
  http://musescore.org/en/developers-handbook/release-notes/release-notes-musescore-1.2
  As usual, a few new features and many bugfixes.
* Thu Jul 28 2011 cgardner@suse.com
- Version 1.1, released 27 July 2011.  See
  http://musescore.org/en/developers-handbook/release-notes-musescore-1.1
  Many new features, and more than 60 bugs fixed.
* Thu May 26 2011 cgardner@suse.de
- Fixed compiler problem introduced by gcc 4.6
* Tue Feb  8 2011 cgardner@novell.com
- Removed lilypond from BuildRequires.  It's clearly not needed.
  Thanks to Nicolas Froment for pointing this out.
* Mon Feb  7 2011 cgardner@novell.com
- First major release, version 1.0.  See http://musescore.org/en/node/9020
  Several new features, scores of bug fixes.
* Tue Oct  5 2010 cgardner@novell.com
- update to version 0.9.6.3, with the following bug fixes:
  * fix #6775: Seg. fault by double clicking any element twice
  * fix #7233: Transpose by diminished second doesn't work (0.9.6 branch regression)
  * fix #7232: D.S. after coda sign freezes playback
  * fix #7167: Time signature change causes triplets to corrupt score
  * fix #7211: Copy/Paste notes over rest of diff. durations in staves
  * fix #7142: Crescendo & delete measures problems
  * fix #7197: MuseScore fails to open MSCZ files with capitals
  * fix #6932: Changing notehead of a breve crash
  * fix #7077: Applying double-note tremolo to dotted notes fails and alter measure duration
  * fix #6937: Measure Properties should be modal dialog
  * fix #6888: When exchanging voice, voice 1 is removed
  * fix get keysig from plugin when concert pitch mode is set
  * fix #6735: C# for AltoSax in default soundfont is silent
  * add access to DPI and notehead, note boundingbox and note position from plugin framework
  * fix #7150: Changing soundfont does not work for audio export
* Tue Sep 14 2010 cgardner@novell.com
- update to version 0.9.6.2, with the following bug fixes:
  15.aug (la)
  * fix #6658: Natural in every keysig on mac PPC
  * fix #6508: Crash removing instrument with volta
  * fix #6706: Crash when inserting slurs from palette while editing text
  * fix #6740: Autosave works only the first time
  10.aug (ws)
  * fix repeat command (ctrl+r) for staves > 1
  6.aug (ws)
  * attempt to fix font problem (quarternote looks too big in text)
  5.aug (la)
  * fix #6479: Crash when closing score during playback
  * fix #6505: Mixer is not refreshed when scores are switched
  4.aug (la)
  * fix #6597: Close/reload crash on XP
  * fix #6624: Crash when deleting a tuplet from a MusicXML import
  * fix cursor move on repeatmeasure in plugin framework
  * fix instrument name containing flats for plugin framework
  14.jul (ws)
  * fix mouse wheel handling for mixer elements
* Thu Jul  8 2010 cgardner@novell.com
- update to version 0.9.6
  "branched" to multimedia project.
* Thu Nov 26 2009 lars@linux-schulserver.de
- update to version 0.9.5
* Wed Nov 19 2008 lars@linux-schulserver.de
- build for openSUSE-Education
- fix some failures detected by rpmlint
* Sat Oct 25 2008 jvrdld <jvrdld@opensuse.org>
- updated to version 0.9.3
* Sat Feb  9 2008 Carlos Goncalves <cgoncalves@opensuse.org>
- updated to version 0.9.1
* Mon Jul 30 2007 Carlos Goncalves <cgoncalves@opensuse.org>
- updated to version 0.6.1
  * This is a bugfix release fixing the midi import crash and adding
  some small usability enhancements.
* Sat Jul 28 2007 Carlos Goncalves <cgoncalves@opensuse.org>
- initial package
